package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.WrongValueException;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Checkbox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.Label;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Radio;
import org.zkoss.zul.Radiogroup;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.ClienteCorporativo;
import com.rjconsultores.ventaboletos.entidad.ContratoCorporativo;
import com.rjconsultores.ventaboletos.entidad.GrupoContrato;
import com.rjconsultores.ventaboletos.exception.BusinessException;
import com.rjconsultores.ventaboletos.service.ClienteCorporativoService;
import com.rjconsultores.ventaboletos.service.ContratoService;
import com.rjconsultores.ventaboletos.service.GrupoContratoService;
import com.rjconsultores.ventaboletos.utilerias.UsuarioLogado;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxClienteCorporativo;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxUsuario;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;

import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@Controller("editarContratoController")
@Scope("prototype")
public class EditarContratoController extends MyGenericForwardComposer {

	private static final String TITULO = "editarContratoController.window.title";
	private static final long serialVersionUID = 1L;
	@Autowired
	private ContratoService contratoService;
	@Autowired	
	private ClienteCorporativoService clienteService;
	@Autowired
	private GrupoContratoService grupoService;
	
	private List<GrupoContrato> lsGrupo;

	private ContratoCorporativo contrato;
	private MyListbox contratoList;
	
	//Contrato	
	private Textbox txtNumContrato;
	private Datebox datInicial;
	private Datebox datFinal;
	private MyComboboxClienteCorporativo cmbCliente;
	private MyComboboxEstandar cmbGrupo;
	private MyComboboxUsuario cmbRepresentante;
	private Radiogroup rdgTipoCalculo;
	private Radiogroup rdgTipoTarifa;
	private Radiogroup rdgTipoContrato;
	private Radiogroup rdgStatus;
	
	//Config
	private Checkbox chkBilheteAberto;
	private Checkbox chkBilhetesConfirmados;
	private Checkbox chkReservaBilhete;
	private Checkbox chkManipulaBonus;
	private Checkbox chkExigeExcedente;
	
	//Cliente
	private Label lblClienteEmail;
	private Label lblClienteTelefone;
	private Label lblClienteLogradouro;
	private Label lblClienteNumero;
	private Label lblClienteCEP;
	private Label lblClienteComplemento;
	private Label lblClienteBairro;

	@Override
	public void doAfterCompose(Component comp) throws Exception {			
		lsGrupo = grupoService.obtenerTodos();
		
		super.doAfterCompose(comp);
		
		contrato = (ContratoCorporativo) Executions.getCurrent().getArg().get("contrato");
		contratoList = (MyListbox) Executions.getCurrent().getArg().get("contratoList");
		
		preencheCombo();
		preencheRadios();
		preencheCheckBox();
		preencheDadosCliente();
	}

	public void onClick$btnSalvar(Event ev) throws InterruptedException {
		try {
			if( cmbCliente.getSelectedItem() != null ) {
				contrato.setClienteCorporativoId( cmbCliente.getSelectedCliente().getClienteCorporativoId());
				contrato.setNomeClienteCorp(cmbCliente.getSelectedCliente().getNomeClienteCorp());
			}
			
			Comboitem grupo = cmbGrupo.getSelectedItem();
			if( grupo != null ) {
				GrupoContrato item = (GrupoContrato)grupo.getValue();
				contrato.setGrupoContratoId( item.getGrupoContratoId() );
				contrato.setNomeGrupoContrato( item.getNomeGrupoContrato() );
			}
			
			if( cmbRepresentante.getSelectedItem() != null ) {
				contrato.setUsuarioRepId( cmbRepresentante.getSelectedUsuario().getUsuarioId());
			}
			
			if( rdgTipoCalculo.getSelectedItem() !=null ) {
				contrato.setTipoCalculo( Integer.valueOf(rdgTipoCalculo.getSelectedItem().getValue()));
			}
			
			if( rdgTipoTarifa.getSelectedItem() !=null ) {
				contrato.setTipoTarifa( Integer.valueOf(rdgTipoTarifa.getSelectedItem().getValue()));
			}
			
			if( rdgTipoContrato.getSelectedItem() !=null ) {
				contrato.setTipoContrato( Integer.valueOf(rdgTipoContrato.getSelectedItem().getValue()));
			}
			
			if( rdgStatus.getSelectedItem() !=null ) {
				contrato.setStatusContrato( Integer.valueOf(rdgStatus.getSelectedItem().getValue()));
			}
			
			contrato.setIndBilhetesAbertos(chkBilheteAberto.isChecked());
			contrato.setIndBilhetesConfirmados(chkBilhetesConfirmados.isChecked());
			contrato.setIndExigeExcedente(chkExigeExcedente.isChecked());
			contrato.setIndManipulaBonus(chkManipulaBonus.isChecked());
			contrato.setIndReservaBilhete(chkReservaBilhete.isChecked());
			
			contratoService.suscribirActualizar(contrato);
			contratoList.updateItem(contrato);

			Messagebox.show(
					Labels.getLabel("MSG.suscribirOK"),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.INFORMATION);

			closeWindow();
		} catch (BusinessException ex) {
			Messagebox.show(
					ex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);
		} catch (WrongValueException wex) {
			Messagebox.show(
					wex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);			
		} catch (Exception ex) {
			Messagebox.show(
						Labels.getLabel("MSG.Error"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.ERROR);
		}
	}

	public void onClick$btnApagar(Event ev) throws InterruptedException {
		Integer resp = Messagebox.show(
					Labels.getLabel("MSG.borrarPergunta"),
					Labels.getLabel(TITULO),
					Messagebox.YES | Messagebox.NO, Messagebox.QUESTION);

		if (resp == Messagebox.YES) {

			contratoService.borrar(contrato);

			Messagebox.show(
						Labels.getLabel("MSG.borrarOK"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.INFORMATION);

			contratoList.removeItem(contrato);

			closeWindow();
		}
	}
	
	public void onChange$cmbCliente(Event ev) {
		preencheDadosCliente();
	}

	private void preencheDadosCliente() {
		if( cmbCliente.getSelectedItem() != null ) {
			ClienteCorporativo cliente = cmbCliente.getSelectedCliente();
			lblClienteEmail.setValue(cliente.getEmail());			
			lblClienteTelefone.setValue(cliente.getTelefone());
			lblClienteLogradouro.setValue(cliente.getLogradouro());
			lblClienteNumero.setValue(cliente.getNumero());
			lblClienteCEP.setValue(cliente.getCep());
			lblClienteComplemento.setValue(cliente.getComplemento());
			lblClienteBairro.setValue(cliente.getBairro());
		}
	}
	
	private void preencheCombo() {
		cmbCliente.setSelectedCliente(contrato.getClienteCorporativoId());
		
		if(UsuarioLogado.isUsuarioAdmContrato()) {
			cmbRepresentante.setSelectedUsuario(UsuarioLogado.getUsuarioLogado());
			cmbRepresentante.setDisabled(true);
		}else {
			cmbRepresentante.setSelectedUsuario(contrato.getUsuarioRepId());
		}
		
		if(contrato.getGrupoContratoId() != null ) {
			GrupoContrato grupo = grupoService.obtenerID(contrato.getGrupoContratoId());
			Comboitem ciGrupo = new Comboitem(grupo.toString());
			ciGrupo.setAttribute("value", grupo);
			ciGrupo.setValue(grupo);
			ciGrupo.setParent(cmbGrupo);
			cmbGrupo.setSelectedItem(ciGrupo);			
		}
	}

	private void preencheCheckBox() {
		chkBilheteAberto.setChecked(contrato.isIndBilhetesAbertos());
		chkBilhetesConfirmados.setChecked(contrato.isIndBilhetesConfirmados());
		chkExigeExcedente.setChecked(contrato.isIndExigeExcedente());
		chkManipulaBonus.setChecked(contrato.isIndManipulaBonus());
		chkReservaBilhete.setChecked(contrato.isIndReservaBilhete());
	}
	
	private void preencheRadios() {
		if( contrato.getTipoCalculo() !=null ) {
			for (Object filho : rdgTipoCalculo.getChildren()) {
				Radio rd = (Radio)filho;
				if(rd.getValue().equals( contrato.getTipoCalculo().toString())){
					rdgTipoCalculo.setSelectedItem(rd);
					break;
				}
			}
		}
		
		if( contrato.getTipoContrato() !=null ) {
			for (Object filho : rdgTipoContrato.getChildren()) {
				Radio rd = (Radio)filho;
				if(rd.getValue().equals( contrato.getTipoContrato().toString())){
					rdgTipoContrato.setSelectedItem(rd);
					break;
				}
			}
		}
		
		if( contrato.getTipoTarifa() !=null ) {
			for (Object filho : rdgTipoTarifa.getChildren()) {
				Radio rd = (Radio)filho;
				if(rd.getValue().equals( contrato.getTipoTarifa().toString())){
					rdgTipoTarifa.setSelectedItem(rd);
					break;
				}
			}
		}
		
		if( contrato.getStatusContrato() !=null ) {
			for (Object filho : rdgStatus.getChildren()) {
				Radio rd = (Radio)filho;
				if(rd.getValue().equals( contrato.getStatusContrato().toString())){
					rdgStatus.setSelectedItem(rd);
					break;
				}
			}
		}		
	}

}
