package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.Executions;
import org.zkoss.zk.ui.WrongValueException;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Button;
import org.zkoss.zul.Messagebox;
import org.zkoss.zul.Radio;
import org.zkoss.zul.Radiogroup;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Transportadora;
import com.rjconsultores.ventaboletos.service.TransportadoraService;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;

import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@Controller("editarTransportadoraController")
@Scope("prototype")
public class EditarTransportadoraController extends MyGenericForwardComposer {

	private static final String TITULO = "editarTransportadoraController.window.title";
	private static final long serialVersionUID = 1L;
	@Autowired
	private TransportadoraService transportadoraService;

	private Transportadora transportadora;
	private MyListbox transportadoraList;

	private Textbox txtNit;
	private Textbox txtNome;
	private Radiogroup rdgClassePagamento;
	
	private Button btnApagar;
	private Button btnSalvar;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		
		super.doAfterCompose(comp);
		
		transportadora = (Transportadora) Executions.getCurrent().getArg().get("transportadora");
		transportadoraList = (MyListbox) Executions.getCurrent().getArg().get("transportadoraList");
		
		if(! isRegistroNovo(transportadora.getTransportadoraId()) ) {
			btnApagar.setVisible(transportadora.isActivo());
			btnSalvar.setVisible(transportadora.isActivo());
		}
		
		preencheCombo();
		preencheRadios();
	}

	public void onClick$btnSalvar(Event ev) throws InterruptedException {
		try {
			
			if( rdgClassePagamento.getSelectedItem() !=null ) {
				transportadora.setClassePagamento( Integer.valueOf(rdgClassePagamento.getSelectedItem().getValue()));
			}
			
			if (isRegistroNovo(transportadora.getTransportadoraId())) {
                if (transportadoraService.existe(transportadora.getNit())) {
                    Messagebox.show(
                            Labels.getLabel("MSG.Registro.Existe"),
                            Labels.getLabel(TITULO),
                            Messagebox.OK, Messagebox.EXCLAMATION);
                    return;
                }
                transportadoraService.suscribir(transportadora);
                transportadoraList.addItemNovo(transportadora);
            } else {
                transportadoraService.actualizacion(transportadora);
                transportadoraList.updateItem(transportadora);
            }

			Messagebox.show(
					Labels.getLabel("MSG.suscribirOK"),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.INFORMATION);

			closeWindow();		
		} catch (WrongValueException wex) {
			Messagebox.show(
					wex.getMessage(),
					Labels.getLabel(TITULO),
					Messagebox.OK, Messagebox.ERROR);			
		} catch (Exception ex) {
			Messagebox.show(
						Labels.getLabel("MSG.Error"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.ERROR);
		}
	}

	public void onClick$btnApagar(Event ev) throws InterruptedException {
		Integer resp = Messagebox.show(
					Labels.getLabel("MSG.borrarPergunta"),
					Labels.getLabel(TITULO),
					Messagebox.YES | Messagebox.NO, Messagebox.QUESTION);

		if (resp == Messagebox.YES) {

			transportadoraService.borrar(transportadora);

			Messagebox.show(
						Labels.getLabel("MSG.borrarOK"),
						Labels.getLabel(TITULO),
						Messagebox.OK, Messagebox.INFORMATION);

			transportadoraList.removeItem(transportadora);

			closeWindow();
		}
	}
	
	private void preencheCombo() {
/*		
		if(transportadora.getGrupoTransportadoraId() != null ) {
			GrupoTransportadora grupo = formaPagoService.obtenerID(transportadora.getGrupoTransportadoraId());
			Comboitem ciGrupo = new Comboitem(grupo.toString());
			ciGrupo.setAttribute("value", grupo);
			ciGrupo.setValue(grupo);
			ciGrupo.setParent(cmbGrupo);
			cmbGrupo.setSelectedItem(ciGrupo);			
		}
*/	}
	
	private void preencheRadios() {
		if( transportadora.getClassePagamento() !=null ) {
			for (Object filho : rdgClassePagamento.getChildren()) {
				Radio rd = (Radio)filho;
				if(rd.getValue().equals( transportadora.getClassePagamento().toString())){
					rdgClassePagamento.setSelectedItem(rd);
					break;
				}
			}
		}		
	}

}
